==> grunt-dust-html-0.1.1.tgz: package/tasks/grunt-dust-html.js <==
/*
 * Grunt Dust-HTML
 * https://github.com/ehynds/grunt-dust-html
 *
 * Copyright (c) 2013 Eric Hynds
 * Licensed under the MIT license.
 */

module.exports = function(grunt) {
  "use strict";

  var path = require("path");
  var fs = require("fs");

  grunt.registerMultiTask("dusthtml", "Render Dust templates against a context to produce HTML", function() {
    var dust;

    // find me some dust
    try {
      dust = require("dust");
    } catch(err) {
      dust = require("dustjs-linkedin");
    }

    var done = this.async();
    var opts = this.options({
      basePath: ".",
      defaultExt: ".dust",
      whitespace: false,
      context: {}
    });

    // Load includes/partials from the filesystem properly
    dust.onLoad = function(filePath, callback) {
      // Make sure the file to load has the proper extension
      if(!path.extname(filePath).length) {
        filePath += opts.defaultExt;
      }

      if(filePath.charAt(0) !== "/") {
        filePath = opts.basePath + "/" + filePath;
      }

      fs.readFile(filePath, "utf8", function(err, html) {
        if(err) {
          grunt.warn("Template " + err.path + " does not exist");
          return callback(err);
        }

        try {
          callback(null, html);
        } catch(err) {
          parseError(err, filePath);
        }
      });
    };

    this.files.forEach(function(f) {
      f.src.forEach(function(srcFile) {
        var context = opts.context;
        var tmpl;

        try {
          tmpl = dust.compileFn(grunt.file.read(srcFile));
        } catch(err) {
          parseError(err, srcFile);
        }

        // preserve whitespace?
        if(opts.whitespace) {
          dust.optimizers.format = function(ctx, node) {
            return node;
          };
        }

        // if context is a string assume it's a file location
        if(typeof opts.context === "string") {
          try {
            context = grunt.file.readJSON(opts.context);
          } catch(e) {
            grunt.fatal("An error occurred parsing " + opts.context + ". Is it valid JSON?");
          }
        }

        // parse and save as html
        tmpl(context, function(err, html) {
          grunt.file.write(f.dest, html);
          grunt.log.writeln('File "' + f.dest + '" created.');
          done();
        });
      });
    });
  });

  function parseError(err, filePath) {
    grunt.fatal("Error parsing dust template: " + err + " " + filePath);
  }

};

==> grunt-dust-html-0.1.6.tgz: package/tasks/grunt-dust-html.js <==
/*
 * Grunt Dust-HTML
 * https://github.com/ehynds/grunt-dust-html
 *
 * Copyright (c) 2013 Eric Hynds
 * Licensed under the MIT license.
 */

module.exports = function(grunt) {
  "use strict";

  var path = require("path");
  var fs = require("fs");
  var _ = require("lodash");
  var async = require("async");

  grunt.registerMultiTask("dusthtml", "Render Dust templates against a context to produce HTML", function() {
    var dust;
    var done = this.async();
    var opts = this.options({
      basePath: ".",
      defaultExt: ".dust",
      whitespace: false,
      module: "dustjs-linkedin", // dust, dustjs-helpers, or dustjs-linkedin
      context: {}
    });

    // Require dust
    try {
      dust = require(opts.module);
    } catch(err) {
      grunt.fail.fatal("Unable to find the " + opts.module + " dependency. Did you npm install it?");
    }

    // Load includes/partials from the filesystem properly
    dust.onLoad = function(filePath, callback) {
      // Make sure the file to load has the proper extension
      if(!path.extname(filePath).length) {
        filePath += opts.defaultExt;
      }

      if(filePath.charAt(0) !== "/") {
        filePath = opts.basePath + "/" + filePath;
      }

      fs.readFile(filePath, "utf8", function(err, html) {
        if(err) {
          grunt.warn("Template " + err.path + " does not exist");
          return callback(err);
        }

        try {
          callback(null, html);
        } catch(err) {
          parseError(err, filePath);
        }
      });
    };

    async.each(this.files, function(f, callback) {
      f.src.forEach(function(srcFile) {
        var context = opts.context;
        var tmpl;

        // preserve whitespace?
        if(opts.whitespace) {
            dust.optimizers.format = function(ctx, node) {
                return node;
            };
        }

        // pre-compile the template
        try {
          tmpl = dust.compileFn(grunt.file.read(srcFile));
        } catch(err) {
          parseError(err, srcFile);
        }

        // if context is a string assume it's the location to a file
        if(typeof opts.context === "string") {
          context = grunt.file.readJSON(opts.context);

        // if context is an array merge each item together
        } else if(Array.isArray(opts.context)) {
          context = {};

          opts.context.forEach(function(obj) {
            if(typeof obj === "string") {
              obj = grunt.file.readJSON(obj);
            }

            _.extend(context, obj);
          });
        }

        // render template and save as html
        tmpl(context, function(err, html) {
          grunt.file.write(f.dest, html);
          grunt.log.writeln('File "' + f.dest + '" created.');
          callback();
        });
      });
    }, done);
  });

  function parseError(err, filePath) {
    grunt.fatal("Error parsing dust template: " + err + " " + filePath);
  }

};
